==> overlap_0.2.3.tar.gz: overlap/man/densityPlot.Rd <==
\name{densityPlot}
\alias{densityPlot}

\title{
Plot fitted kernel densities
}
\description{
Fits a kernel density function to a data set and plots it.
}
\usage{
densityPlot(A, xscale = 24, xcenter = c("noon", "midnight"),
   add = FALSE, rug = FALSE, n.grid = 128,
   kmax = 3, adjust = 1, ylim, xlab="Time", ylab="Density", ...)
}

\arguments{
  \item{A}{
a vector of times of observations in \emph{radians}, ie. scaled to [\eqn{0, 2\pi}].
}
  \item{xscale}{
The scale for the x axis: 24 (the default) produces a curve with 0 to 24 hours. NA gives a scale in radians, labelled with \eqn{pi}.
}
  \item{xcenter}{
the center of the plot on the x axis: 'noon' (default) or 'midnight'.
}
  \item{add}{
If TRUE, the curve will be added to the existing plot. Use the same settings for xscale and xcenter as for the original plot.
}
  \item{rug}{
If TRUE, the original observations will be displayed as a rug at the bottom of the plot.
}
  \item{n.grid}{
Number of points at which to estimate the density for plotting; 100 is usually adequate to give a smooth-looking curve.
}
  \item{kmax}{
maximum value of k for optimal bandwidth estimation.
}
  \item{adjust}{
bandwidth adjustment (scalar).
}
  \item{xlab, ylab}{
labels for the x and y axes.
}
  \item{ylim}{
optional y limits of the plot; the default goes from 0 to the height of the curve.
}
  \item{\dots}{
Further arguments passed to the plotting functions, such as \code{col}, \code{lty} and \code{lwd}.
}
}

\value{
Returns invisibly a two-column matrix with x and y coordinates which can be used for further plotting; see examples.
}

\author{
Mike Meredith
}

\examples{
# Get example data:
data(simulatedData)

# Do basic plots with defaults:
densityPlot(pigObs, rug=TRUE, main="Simulated data")
densityPlot(tigerObs, add=TRUE, rug=TRUE, col='blue')
legend('topleft', c("Tiger", "Pig"), lty=1, col=c('black', 'blue'), bg='white')
# Add vertical dotted lines to mark sunrise (say 05:30) and sunset (18:47):
# (times must be in hours if the x-axis is labelled in hours)
abline(v=c(5.5, 18+47/60), lty=3)

# A plot centered on midnight:
densityPlot(pigObs, xcenter = "m")
# Mark sunrise/sunset; values to the left of "00:00" are negative
# so subtract 24:
abline(v=c(5.5, (18+47/60) - 24), lty=3)

# Using object returned:
densityPlot(pigObs, xscale=1, rug=TRUE, lwd=3)
# Don't like the rug with lwd = 3!
pigDens <- densityPlot(pigObs, xscale=1, rug=TRUE)
lines(pigDens, lwd=3)

# Plotting time in radians:
densityPlot(pigObs, xscale=NA, rug=TRUE)
densityPlot(tigerObs, xscale=NA, add=TRUE, rug=TRUE, col='red')

}

==> overlap_0.2.7.tar.gz: overlap/man/densityPlot.Rd <==
\name{densityPlot}
\alias{densityPlot}

\title{
Plot fitted kernel densities
}
\description{
Fits a kernel density function to a data set and plots it.
}
\usage{
densityPlot(A, xscale = 24, xcenter = c("noon", "midnight"),
   add = FALSE, rug = FALSE, extend = 'lightgrey',
   n.grid = 128, kmax = 3, adjust = 1, ...)
}

\arguments{
  \item{A}{
a vector of times of observations in \emph{radians}, ie. scaled to [\eqn{0, 2\pi}].
}
  \item{xscale}{
The scale for the x axis: 24 (the default) produces a curve with 0 to 24 hours. NA gives a scale in radians, labelled with \eqn{pi}.
}
  \item{xcenter}{
the center of the plot on the x axis: 'noon' (default) or 'midnight'.
}
  \item{add}{
If TRUE, the curve will be added to the existing plot. Use the same settings for xscale and xcenter as for the original plot.
}
  \item{rug}{
If TRUE, the original observations will be displayed as a rug at the bottom of the plot.
}
  \item{extend}{
If not NULL, the plot extends 3 hours before and after the main 24-hr period, and \code{extend} specifies the background colour; the plot is not extended if \code{extend = NULL}.
}
  \item{n.grid}{
Number of points at which to estimate the density for plotting; 100 is usually adequate to give a smooth-looking curve.
}
  \item{kmax}{
maximum value of k for optimal bandwidth estimation.
}
  \item{adjust}{
bandwidth adjustment (scalar).
}
  \item{\dots}{
Further arguments passed to the plotting functions, such as \code{col, lty, lwd} or \code{xlab, ylab, main}.
}
}

\value{
Returns invisibly a data frame with x and y coordinates which can be used for further plotting or calculations; see examples.
}

\author{
Mike Meredith
}

\examples{
# Get example data:
data(simulatedData)

# Do basic plot with defaults:
densityPlot(pigObs)
# Prettier plots:
densityPlot(pigObs, extend=NULL, lwd=2)
densityPlot(pigObs, rug=TRUE, main="Simulated data", extend='gold')
densityPlot(tigerObs, add=TRUE, rug=TRUE, col='red')
legend('topleft', c("Tiger", "Pig"), lty=1, col=c('black', 'red'), bg='white')
# Add vertical dotted lines to mark sunrise (say 05:30) and sunset (18:47):
# (times must be in hours if the x-axis is labelled in hours)
abline(v=c(5.5, 18+47/60), lty=3)

# A plot centered on midnight:
densityPlot(pigObs, xcenter = "m")
# Mark sunrise/sunset; values to the left of "00:00" are negative
# so subtract 24:
abline(v=c(5.5, (18+47/60) - 24), lty=3)

# Using object returned:
densityPlot(pigObs, rug=TRUE, lwd=3)
# Don't like the rug with lwd = 3?
pigDens <- densityPlot(pigObs, rug=TRUE)
lines(pigDens, lwd=3)
# What proportion of the density lies between 9:00 and 15:00 hrs?
wanted <- pigDens$x > 9 & pigDens$x < 15
mean(pigDens$y[wanted]) * 6  # probability mass for the 6 hr period. 

# Plotting time in radians:
densityPlot(pigObs, xscale=NA, rug=TRUE)
densityPlot(tigerObs, xscale=NA, add=TRUE, rug=TRUE, col='red')

}
